@@ -39,7 +39,7 @@ func (h *HelmHistory) List(ctx context.Context, _ string) ([]runtime.Object, err
 	}
 	ns, n := client.Namespaced(path)
 
-	cfg, err := ensureHelmConfig(h.Client(), ns)
+	cfg, err := ensureHelmConfig(h.Client().Config().Flags(), ns)
 	if err != nil {
 		return nil, err
 	}
@@ -65,7 +65,7 @@ func (h *HelmHistory) Get(_ context.Context, path string) (runtime.Object, error
 	}
 
 	ns, n := client.Namespaced(fqn)
-	cfg, err := ensureHelmConfig(h.Client(), ns)
+	cfg, err := ensureHelmConfig(h.Client().Config().Flags(), ns)
 	if err != nil {
 		return nil, err
 	}
@@ -134,7 +134,7 @@ func (h *HelmHistory) GetValues(path string, allValues bool) ([]byte, error) {
 
 func (h *HelmHistory) Rollback(_ context.Context, path, rev string) error {
 	ns, n := client.Namespaced(path)
-	cfg, err := ensureHelmConfig(h.Client(), ns)
+	cfg, err := ensureHelmConfig(h.Client().Config().Flags(), ns)
 	if err != nil {
 		return err
 	}
@@ -152,7 +152,7 @@ func (h *HelmHistory) Rollback(_ context.Context, path, rev string) error {
 // Delete uninstall a Helm.
 func (h *HelmHistory) Delete(_ context.Context, path string, _ *metav1.DeletionPropagation, _ Grace) error {
 	ns, n := client.Namespaced(path)
-	cfg, err := ensureHelmConfig(h.Client(), ns)
+	cfg, err := ensureHelmConfig(h.Client().Config().Flags(), ns)
 	if err != nil {
 		return err
 	}
