@@ -75,10 +75,12 @@ func hotKeyActions(r Runner, aa ui.KeyActions) error {
 			errs = errors.Join(errs, err)
 			continue
 		}
-		_, ok := aa[key]
-		if ok {
-			errs = errors.Join(errs, fmt.Errorf("duplicated hotkeys found for %q in %q", hk.ShortCut, k))
-			continue
+		if _, ok := aa[key]; ok {
+			if !hk.Override {
+				errs = errors.Join(errs, fmt.Errorf("duplicate hotkey found for %q in %q", hk.ShortCut, k))
+				continue
+			}
+			log.Info().Msgf("Action %q has been overridden by hotkey in %q", hk.ShortCut, k)
 		}
 
 		command, err := r.EnvFn()().Substitute(hk.Command)
@@ -129,11 +131,14 @@ func pluginActions(r Runner, aa ui.KeyActions) error {
 			errs = errors.Join(errs, err)
 			continue
 		}
-		_, ok := aa[key]
-		if ok {
-			errs = errors.Join(errs, fmt.Errorf("duplicated plugin key found for %q in %q", plugin.ShortCut, k))
-			continue
+		if _, ok := aa[key]; ok {
+			if !plugin.Override {
+				errs = errors.Join(errs, fmt.Errorf("duplicate plugin key found for %q in %q", plugin.ShortCut, k))
+				continue
+			}
+			log.Info().Msgf("Action %q has been overridden by plugin in %q", plugin.ShortCut, k)
 		}
+
 		aa[key] = ui.NewKeyActionWithOpts(
 			plugin.Description,
 			pluginAction(r, plugin),
