@@ -9,6 +9,8 @@ import (
 	"strconv"
 	"strings"
 
+	"github.com/derailed/k9s/internal/config"
+
 	"github.com/derailed/k9s/internal/dao"
 	"github.com/derailed/k9s/internal/ui"
 	"github.com/derailed/tcell/v2"
@@ -83,7 +85,8 @@ func (s *ScaleExtender) valueOf(col string) (string, error) {
 }
 
 func (s *ScaleExtender) makeScaleForm(sels []string) (*tview.Form, error) {
-	f := s.makeStyledForm()
+	styles := s.App().Styles.Dialog()
+	f := s.makeStyledForm(styles)
 
 	factor := "0"
 	if len(sels) == 1 {
@@ -126,10 +129,15 @@ func (s *ScaleExtender) makeScaleForm(sels []string) (*tview.Form, error) {
 			s.App().Flash().Infof("%s %s scaled successfully", s.GVR().R(), sels[0])
 		}
 	})
-
 	f.AddButton("Cancel", func() {
 		s.dismissDialog()
 	})
+	for i := 0; i < 2; i++ {
+		if b := f.GetButton(i); b != nil {
+			b.SetBackgroundColorActivated(styles.ButtonFocusBgColor.Color())
+			b.SetLabelColorActivated(styles.ButtonFocusFgColor.Color())
+		}
+	}
 
 	return f, nil
 }
@@ -138,14 +146,14 @@ func (s *ScaleExtender) dismissDialog() {
 	s.App().Content.RemovePage(scaleDialogKey)
 }
 
-func (s *ScaleExtender) makeStyledForm() *tview.Form {
+func (s *ScaleExtender) makeStyledForm(styles config.Dialog) *tview.Form {
 	f := tview.NewForm()
 	f.SetItemPadding(0)
 	f.SetButtonsAlign(tview.AlignCenter).
-		SetButtonBackgroundColor(tview.Styles.PrimitiveBackgroundColor).
-		SetButtonTextColor(tview.Styles.PrimaryTextColor).
-		SetLabelColor(tcell.ColorAqua).
-		SetFieldTextColor(tcell.ColorOrange)
+		SetButtonBackgroundColor(styles.ButtonBgColor.Color()).
+		SetButtonTextColor(styles.ButtonBgColor.Color()).
+		SetLabelColor(styles.LabelFgColor.Color()).
+		SetFieldTextColor(styles.FieldFgColor.Color())
 
 	return f
 }
